@@ -2,19 +2,10 @@ package Sisimai;
 use v5.26;
 use strict;
 use warnings;
-use version; our $VERSION = version->declare('v5.0.3'); our $PATCHLV = 0;
+use version; our $VERSION = version->declare('v5.2.0'); our $PATCHLV = 0;
 sub version { return substr($VERSION->stringify, 1).($PATCHLV > 0 ? 'p'.$PATCHLV : '') }
 sub libname { 'Sisimai' }
 
-sub make {
-    # Emulate "rise" method for the backward compatible
-    warn ' ***warning: Sisimai->make will be removed at v5.1.0. Use Sisimai->rise instead';
-    my $class = shift;
-    my $argv0 = shift // return undef; die ' ***error: wrong number of arguments' if scalar @_ % 2;
-    my $argv1 = { @_ };
-    return __PACKAGE__->rise($argv0, %$argv1);
-}
-
 sub rise {
     # Wrapper method for decoding mailbox or Maildir/
     # @param         [String]  argv0      Path to mbox or Maildir/
@@ -79,6 +70,10 @@ sub dump {
         # Set UTF8 flag before converting to JSON string
         utf8::decode $e->{'subject'};
         utf8::decode $e->{'diagnosticcode'};
+
+        # Backward compatibility until v5.5.0
+        $e->{"smtpagent"} = $e->{"decodedby"};
+        $e->{"smtpcommand"} = $e->{"command"};
     }
 
     require Module::Load;
@@ -164,16 +159,16 @@ Sisimai - Mail Analyzing Interface for bounce mails.
 
 =head1 DESCRIPTION
 
-C<Sisimai> is a library that decodes complex and diverse bounce emails and outputs the results of
-the delivery failure, such as the reason for the bounce and the recipient email address, in
-structured data. It is also possible to output in JSON format.
+B<Sisimai> is a library that decodes complex and diverse bounce emails and outputs the results of
+the delivery failure, such as the reason for the bounce and the recipient email address, in structured
+data. It is also possible to output in JSON format.
 
 =head1 BASIC USAGE
 
 =head2 C<B<rise(I<'/path/to/mbox'>)>>
 
 C<rise()> method provides the feature for getting decoded data as Perl Hash reference from bounced
-email messages as the following. Beginning with v4.25.6, new accessor origin which keeps the path
+email messages as the following. Beginning with v4.25.6, new accessor C<origin> which keeps the path
 to email file as a data source is available.
 
     use Sisimai;
@@ -232,7 +227,7 @@ messages like the following code:
     # dump() method also accepts "delivered" and "vacation" option like the following code:
     my $j = Sisimai->dump('/path/to/mbox', 'delivered' => 1, 'vacation' => 1);
 
-=head1 OTHER WAYS TO PARSE
+=head1 OTHER WAYS TO DECODE
 
 =head2 Read email data from STDIN
 
@@ -243,8 +238,8 @@ C<rise()> method like following command:
 
 =head2 Callback Feature
 
-C<c___> (c and three _s, looks like a fishhook) argument of Sisimai->rise and C<Sisimai->dump()> is
-an array reference and is a parameter to receive code references for callback feature. The first
+C<c___> (C<c> and three C<_>s, looks like a fishhook) argument of Sisimai->rise and C<Sisimai->dump()>
+is an array reference and is a parameter to receive code references for callback feature. The first
 element of C<c___> argument is called at C<Sisimai::Message->sift()> for dealing email headers and
 entire message body. The second element of C<c___> argument is called at the end of each email file
 processing. The result generated by the callback method is accessible via C<Sisimai::Fact->catch>.
@@ -298,8 +293,8 @@ dealing each email file.
                 $e->{'catch'}->{'return-path'} = $1;
             }
 
-            # Save the original email with an additional "X-Sisimai-Parsed:" header to a different PATH.
-            my $a = sprintf("X-Sisimai-Parsed: %d\n", scalar @$fact);
+            # Save the original email with an additional "X-Sisimai-Decoded:" header to a different PATH.
+            my $a = sprintf("X-Sisimai-Decoded: %d\n", scalar @$fact);
             my $p = sprintf("/path/to/another/directory/sisimai-%s.eml", $e->token);
             my $f = IO::File->new($p, 'w');
             my $v = $$mail; $v =~ s/^(From:.+)$/$a$1/m;
@@ -396,7 +391,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
