@@ -10,7 +10,7 @@ sub inquire {
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.0.0
     my $class = shift;
     my $mhead = shift // return undef;
@@ -103,7 +103,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::Biglobe - bounce mail parser class for C<BIGLOBE>.
+Sisimai::Lhost::Biglobe - bounce mail decoder class for BIGLOBE (L<https://www.biglobe.ne.jp/>).
 
 =head1 SYNOPSIS
 
@@ -111,8 +111,8 @@ Sisimai::Lhost::Biglobe - bounce mail parser class for C<BIGLOBE>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::Biglobe parses a bounce email which created by C<BIGLOBE>. Methods in the module are
-called from only Sisimai::Message.
+C<Sisimai::Lhost::Biglobe> decodes a bounce email which created by BIGLOBE L<https://www.biglobe.ne.jp/>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -124,8 +124,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
