@@ -4,13 +4,13 @@ use v5.26;
 use strict;
 use warnings;
 
-sub description { 'Trend Micro InterScan Messaging Security Suite' }
+sub description { 'Trend Micro InterScan Messaging Security Suite: https://www.trendmicro.com/en_us/business/products/user-protection/sps/email-and-collaboration/interscan-messaging.html' }
 sub inquire {
-    # Detect an error from InterScanMSS
+    # Detect an error from Trend Micro InterScan Messaging Security Suite
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.1.2
     my $class = shift;
     my $mhead = shift // return undef;
@@ -93,7 +93,8 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::InterScanMSS - bounce mail parser class for C<Trend Micro InterScan Messaging Security Suite>.
+Sisimai::Lhost::InterScanMSS - bounce mail decoder class for Trend Micro InterScan Messaging Security
+Suite L<https://www.trendmicro.com/en_us/business/products/user-protection/sps/email-and-collaboration/interscan-messaging.html>.
 
 =head1 SYNOPSIS
 
@@ -101,8 +102,9 @@ Sisimai::Lhost::InterScanMSS - bounce mail parser class for C<Trend Micro InterS
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::InterScanMSS parses a bounce email which created by C<Trend Micro InterScan Messaging Security Suite>.
-Methods in the module are called from only Sisimai::Message.
+C<Sisimai::Lhost::InterScanMSS> decodes a bounce email which created by Trend Micro InterScan Messaging
+Security Suite L<https://www.trendmicro.com/en_us/business/products/user-protection/sps/email-and-collaboration/interscan-messaging.html>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -114,8 +116,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
