@@ -4,13 +4,13 @@ use v5.26;
 use strict;
 use warnings;
 
-sub description { 'Verizon Wireless: https://www.verizonwireless.com' }
+sub description { 'Verizon: https://www.verizon.com/' }
 sub inquire {
     # Detect an error from Verizon
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.0.0
     my $class = shift;
     my $mhead = shift // return undef;
@@ -167,7 +167,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::Verizon - bounce mail parser class for C<Verizon Wireless>.
+Sisimai::Lhost::Verizon - bounce mail decoder class for Verizon L<https://www.verizon.com/>.
 
 =head1 SYNOPSIS
 
@@ -175,8 +175,8 @@ Sisimai::Lhost::Verizon - bounce mail parser class for C<Verizon Wireless>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::Verizon parses a bounce email which created by C<Verizon Wireless>. Methods in the
-module are called from only Sisimai::Message.
+C<Sisimai::Lhost::Verizon> decodes a bounce email which created by Verizon L<https://www.verizon.com/>.
+Methods in the module are called from only Sisimai::Message.
 
 =head1 CLASS METHODS
 
@@ -188,8 +188,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
