@@ -4,13 +4,13 @@ use v5.26;
 use strict;
 use warnings;
 
-sub description { 'Zoho Mail: https://www.zoho.com' }
+sub description { 'Zoho Mail: https://www.zoho.com/mail/' }
 sub inquire {
     # Detect an error from Zoho Mail
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.1.7
     my $class = shift;
     my $mhead = shift // return undef;
@@ -117,7 +117,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::Zoho - bounce mail parser class for C<Zoho Mail>.
+Sisimai::Lhost::Zoho - bounce mail decoder class for Zoho Mail L<https://www.zoho.com/mail/>.
 
 =head1 SYNOPSIS
 
@@ -125,8 +125,8 @@ Sisimai::Lhost::Zoho - bounce mail parser class for C<Zoho Mail>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::Zoho parses a bounce email which created by C<Zoho! MAIL>. Methods in the module
-are called from only Sisimai::Message.
+C<Sisimai::Lhost::Zoho> decodes a bounce email which created by Zoho Mail L<https://www.zoho.com/mail/>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -138,8 +138,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
