@@ -16,6 +16,7 @@ sub match {
 
     state $index = [
         'exceeded maximum inbound message size',
+        'exceeded the maximum incoming message size',
         'line limit exceeded',
         'max message size exceeded',
         'message file too big',
@@ -53,8 +54,7 @@ sub true {
 
     #  5.2.3   Message length exceeds administrative limit
     return 0 if( $tempreason eq 'exceedlimit' || $statuscode eq '5.2.3' );
-    return 1 if __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
-    return 0;
+    return __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
 }
 
 1;
