@@ -61,10 +61,10 @@ Sisimai::Reason::NetworkError - Bounce reason is C<networkerror> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::NetworkError checks the bounce reason is C<networkerror> or not. This class is called
-only Sisimai::Reason class.
+C<Sisimai::Reason::NetworkError> checks the bounce reason is C<networkerror> or not. This class is
+called only C<Sisimai::Reason> class.
 
-This is the error that SMTP connection failed due to DNS look up failure or other network problems.
+This is the error that the SMTP connection failed due to DNS look up failure or other network problems.
 This reason has added in Sisimai 4.1.12.
 
     A message is delayed for more than 10 minutes for the following
@@ -76,20 +76,20 @@ This reason has added in Sisimai 4.1.12.
 
 =head2 C<B<text()>>
 
-C<text()> returns string: C<networkerror>.
+C<text()> method returns the fixed string C<networkerror>.
 
     print Sisimai::Reason::NetworkError->text;  # networkerror
 
 =head2 C<B<match(I<string>)>>
 
-C<match()> returns 1 if the argument matched with patterns defined in this class.
+C<match()> method returns C<1> if the argument matched with patterns defined in this class.
 
     print Sisimai::Reason::NetworkError->match('5.3.5 System config error'); # 1
 
 =head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> returns 1 if the bounce reason is C<networkerror>. The argument must be Sisimai::Fact
-object and this method is called only from Sisimai::Reason class.
+C<true()> method returns C<1> if the bounce reason is C<networkerror>. The argument must be C<Sisimai::Fact>
+object and this method is called only from C<Sisimai::Reason> class.
 
 =head1 AUTHOR
 
