@@ -178,7 +178,7 @@ sub true {
         }
         return 1 unless $matchother;    # Did not match with other message patterns
 
-    } elsif( $argvs->{'smtpcommand'} eq 'RCPT' ) {
+    } elsif( $argvs->{'command'} eq 'RCPT' ) {
         # When the SMTP command is not "RCPT", the session rejected by other reason, maybe.
         return 1 if __PACKAGE__->match($issuedcode);
     }
