@@ -4,14 +4,14 @@ use strict;
 use warnings;
 
 # https://www.godaddy.com/help/what-does-my-email-bounceback-mean-3568
-sub get {
+sub find {
     # Detect bounce reason from GoDaddy (smtp.secureserver.net)
     # @param    [Sisimai::Fact] argvs   Decoded email object
     # @return   [String]                The bounce reason for GoDaddy
     # @see      https://ca.godaddy.com/help/fix-rejected-email-with-a-bounce-error-40685
     # @since v4.22.2
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argvs = shift // return undef; return "" unless $argvs->{'diagnosticcode'};
 
     state $errorcodes = {
         # Sender bounces
@@ -244,14 +244,14 @@ Sisimai::Rhost::GoDaddy - Detect the bounce reason returned from GoDaddy.
 =head1 DESCRIPTION
 
 C<Sisimai::Rhost::GoDaddy> detects the bounce reason from the content of C<Sisimai::Fact> object as
-an argument of C<get()> method when the value of C<rhost> of the object end with C<secureserver.net>.
+an argument of C<find()> method when the value of C<rhost> of the object end with C<secureserver.net>.
 This class is called only C<Sisimai::Fact> class.
 
 =head1 CLASS METHODS
 
-=head2 C<B<get(I<Sisimai::Fact Object>)>>
+=head2 C<B<find(I<Sisimai::Fact Object>)>>
 
-C<get()> method detects the bounce reason.
+C<find()> method detects the bounce reason.
 
 =head1 AUTHOR
 
